enums/days_in_months library

Enums

DaysInMonth
An enum that stores how many does a month normally has The enums are named by the name of the months, i.e. all 12 of them

Functions

isLeapYear(int year) bool
A method to check whether the passed year is leap year or not.