TimeRange class
A class to store the range for each unit of time Both start and end attributes are nullable.
If start is null, the current value of unit is taken If end is null, the max value of unit is taken, i.e., for months, 12 is max value, for hours, 23 is max value, for years futureYearLimit of RandomDTOptions is max value.
Keep in mind that start and end are both inclusive
To keep a single value using range, set start and end to the same value
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited